<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>KWin::SplitMenu</name>
    <message>
        <source>Tile window to left of screen</source>
        <translation>Pencereyi ekranın soluna döşe</translation>
    </message>
    <message>
        <source>Tile window to right of screen</source>
        <translation>Pencereyi ekranın sağına döşe</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Ekranı Kapla</translation>
    </message>
    <message>
        <source>Unmaximize</source>
        <translation>Önceki Boyut</translation>
    </message>
</context>
</TS>